# flake8-vyper

Flake8 wrapper to support Vyper.  This is experimental, so, beware.

## Install

    pip install flake8-vyper

## Usage

You can run flake8 with this wrapper with the command `flake8-vyper`.
